@@ -2,7 +2,7 @@
  * @file   gui-import.c
  * @brief
  *
- * Copyright (C) 2009-2012 Gummi-Dev Team <alexvandermey@gmail.com>
+ * Copyright (C) 2009 Gummi Developers
  * All Rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person
@@ -45,17 +45,17 @@ GuImportGui* importgui_init (GtkBuilder* builder) {
     g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
 
     GuImportGui* i = g_new0 (GuImportGui, 1);
-    
+
     i->import_panel =
-        GTK_HBOX (gtk_builder_get_object (builder, "import_panel"));
-        
+        GTK_BOX (gtk_builder_get_object (builder, "import_panel"));
+
     i->image_pane =
         GTK_VIEWPORT (gtk_builder_get_object (builder, "imp_pane_image"));
     i->table_pane =
         GTK_VIEWPORT (gtk_builder_get_object (builder, "imp_pane_table"));
     i->matrix_pane =
         GTK_VIEWPORT (gtk_builder_get_object (builder, "imp_pane_matrix"));
-    i->biblio_pane = 
+    i->biblio_pane =
         GTK_VIEWPORT (gtk_builder_get_object (builder, "imp_pane_biblio"));
 
     i->image_file =
@@ -84,9 +84,9 @@ GuImportGui* importgui_init (GtkBuilder* builder) {
         GTK_ADJUSTMENT (gtk_builder_get_object (builder, "matrix_cols"));
     i->matrix_combobracket =
         GTK_COMBO_BOX (gtk_builder_get_object (builder,"matrix_combobracket"));
-        
-    i->biblio_file = 
-         GTK_ENTRY (gtk_builder_get_object (builder, "biblio_file"));   
+
+    i->biblio_file =
+         GTK_ENTRY (gtk_builder_get_object (builder, "biblio_file"));
 
     gtk_adjustment_set_value (i->table_cols, 3);
     gtk_adjustment_set_value (i->table_rows, 3);
@@ -95,65 +95,9 @@ GuImportGui* importgui_init (GtkBuilder* builder) {
     return i;
 }
 
-/*
-G_MODULE_EXPORT
-void on_import_tabs_switch_page (GtkNotebook* notebook, GtkNotebookPage* page,
-        guint page_num, void* user) {
-    GList* list = NULL;
-    list = gtk_container_get_children (
-            GTK_CONTAINER (g_importgui->box_image));
-            
-
-    while (list) {
-        gtk_container_remove (GTK_CONTAINER (g_importgui->box_image),
-                GTK_WIDGET (list->data));
-        list = list->next;
-    }
-    list = gtk_container_get_children (
-            GTK_CONTAINER (g_importgui->box_table));
-    while (list) {
-        gtk_container_remove (GTK_CONTAINER (g_importgui->box_table),
-                GTK_WIDGET (list->data));
-        list = list->next;
-    }
-    list = gtk_container_get_children (
-            GTK_CONTAINER (g_importgui->box_matrix));
-    while (list) {
-        gtk_container_remove (GTK_CONTAINER (g_importgui->box_matrix),
-                GTK_WIDGET (list->data));
-        list = list->next;
-    }
-    list = gtk_container_get_children (
-            GTK_CONTAINER (g_importgui->box_biblio));
-    while (list) {
-        gtk_container_remove (GTK_CONTAINER (g_importgui->box_biblio),
-                GTK_WIDGET (list->data));
-        list = list->next;
-    }
-
-    switch (page_num) {
-        case 1:
-            gtk_container_add (GTK_CONTAINER (g_importgui->box_image),
-                    GTK_WIDGET (g_importgui->image_pane));
-            break;
-        case 2:
-            gtk_container_add (GTK_CONTAINER (g_importgui->box_table),
-                    GTK_WIDGET (g_importgui->table_pane));
-            break;
-        case 3:
-            gtk_container_add (GTK_CONTAINER (g_importgui->box_matrix),
-                    GTK_WIDGET (g_importgui->matrix_pane));
-        case 4:
-            gtk_container_add (GTK_CONTAINER (g_importgui->box_biblio),
-                    GTK_WIDGET (g_importgui->biblio_pane));
-            break;
-    }
-}
-*/
-
 void importgui_remove_all_panels () {
     GList* list = NULL;
-    
+
     list = gtk_container_get_children (
             GTK_CONTAINER (g_importgui->import_panel));
     while (list) {
@@ -232,7 +176,7 @@ void on_import_image_apply_clicked (GtkWidget* widget, void* user) {
                 root_path = g_path_get_dirname (g_active_editor->filename);
             relative_path = utils_path_to_relative (root_path, imagefile);
             text =importer_generate_image(relative_path, caption, label, scale);
-            editor_insert_package (g_active_editor, "graphicx");
+            editor_insert_package (g_active_editor, "graphicx", NULL);
             editor_get_current_iter (g_active_editor, &current);
             gtk_text_buffer_begin_user_action (g_e_buffer);
             gtk_text_buffer_insert (g_e_buffer, &current,text,strlen (text));
@@ -254,7 +198,7 @@ void on_import_matrix_apply_clicked (GtkWidget* widget, void* user) {
     gint rows = gtk_adjustment_get_value (g_importgui->matrix_rows);
     gint cols = gtk_adjustment_get_value (g_importgui->matrix_cols);
     const gchar* text = importer_generate_matrix (bracket, rows, cols);
-    editor_insert_package (g_active_editor, "amsmath");
+    editor_insert_package (g_active_editor, "amsmath", NULL);
     editor_get_current_iter (g_active_editor, &current);
     gtk_text_buffer_begin_user_action (g_e_buffer);
     gtk_text_buffer_insert (g_e_buffer, &current, text, strlen (text));
@@ -268,7 +212,7 @@ void on_import_biblio_apply_clicked (GtkWidget* widget, void* user) {
     gchar* basename = NULL;
     gchar* root_path = NULL;
     gchar* relative_path = NULL;
-    
+
     const gchar* filename = gtk_entry_get_text (g_importgui->biblio_file);
 
     if ((filename) && (strlen(filename) != 0)) {
@@ -289,7 +233,7 @@ void on_import_biblio_apply_clicked (GtkWidget* widget, void* user) {
 G_MODULE_EXPORT
 void on_image_file_activate (void) {
     gchar* filename = NULL;
-    
+
     filename = get_open_filename (TYPE_IMAGE);
     if (filename) {
         importer_imagegui_set_sensitive (filename, TRUE);
@@ -300,7 +244,7 @@ void on_image_file_activate (void) {
 G_MODULE_EXPORT
 void on_biblio_file_activate (GtkWidget *widget, void * user) {
     gchar* filename = NULL;
-    
+
     filename = get_open_filename (TYPE_BIBLIO);
     if (filename) {
         gtk_entry_set_text (g_importgui->biblio_file, filename);
